{{- define "keycloak.init.container" -}}
- name: keycloak-init
  image: "{{ .Values.keycloak.init.image.registry }}/{{ .Values.keycloak.init.image.name }}:{{ .Values.keycloak.init.image.tag }}"
  imagePullPolicy: {{ .Values.keycloak.init.imagePullPolicy | default "IfNotPresent" }}
  command:
    - /bin/sh
    - -c
    - |
      /opt/kublr/keycloak-init server \
         --keycloak-server=http://127.0.0.1:8080 \
         --keycloak-admin-username={{ .Values.keycloak.username }} \
         --keycloak-admin-password=$(KEYCLOAK_PASSWORD) \
         --insecure-skip-tls-verify=true \
         --config=/etc/keycloak-init/kublr-ui.conf \
         --output=kubernetes-secret \
         --output-kubernetes-secret-namespace=$(KUBERNETES_NAMESPACE) \
         --output-kubernetes-secret-name={{ include "keycloak.fullname" . }}-lock \
         --verbose=false \
         --wait-timeout=10m0s \
      && /bin/sleep infinite
  env:
  - name: KEYCLOAK_PASSWORD
    valueFrom:
      secretKeyRef:
        {{- if .Values.keycloak.existingSecret }}
        name: {{ tpl .Values.keycloak.existingSecret . }}
        key: {{ .Values.keycloak.existingSecretKey }}
        {{- else }}
        name: {{ include "keycloak.fullname" . }}-http
        key: password
        {{- end }}
  - name: KUBERNETES_NAMESPACE
    valueFrom:
      fieldRef:
        fieldPath: metadata.namespace
  volumeMounts:
  - name: keycloak-init-config
    mountPath: /etc/keycloak-init
{{- end -}}

{{- define "keycloak.init.volume" -}}
- name: keycloak-init-config
  configMap:
    name:  {{ include "keycloak.fullname" . }}-init
{{- end -}}
