{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 24 -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 24 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
*/}}
{{- define "fullname" -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- printf "%s-%s" .Release.Name $name -}}
{{- end -}}


{{/*
Expand the name of the elasticsearch part of chart.
*/}}
{{- define "elasticsearch.name" -}}
{{- default .Chart.Name .Values.elasticsearch.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
*/}}
{{- define "elasticsearch.fullname" -}}
{{- if .Values.elasticsearch.fullnameOverride -}}
{{- .Values.elasticsearch.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.elasticsearch.nameOverride -}}
{{- if contains $name .Release.Name -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Create a default fully qualified client name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
*/}}
{{- define "elasticsearch.client.fullname" -}}
{{ template "elasticsearch.fullname" . }}-client
{{- end -}}



{{- define "image" -}}
{{- $config := index . 0 -}}
{{- $base := index . 1 -}}
{{- $ := index . 2 -}}
{{- $suffix := "-oss" -}}
{{- if $.Values.elasticsearch.xpackEnabled -}}
{{- $suffix = "" -}}
{{- end -}}
{{- $name := default (printf "%s%s" $base $suffix) $config.name -}}
{{- $config.registry }}/{{- $name -}}:{{ $config.tag }}
{{- end -}}


{{- define "elasticsearch.image" -}}
{{- $config := $.Values.elasticsearch.image -}}
{{- $base := "elasticsearch/elasticsearch" -}}
{{- if .Values.searchguard.enabled -}}
{{- $config = $.Values.searchguard.elasticsearch.image -}}
{{- $base = "kublr/elasticsearch-sg" -}}
{{- end -}}
{{- include "image" (list $config $base $ )}}
{{- end -}}


{{- define "kibana.image" -}}
{{- $config := $.Values.kibana.image -}}
{{- $base := "kibana/kibana" -}}
{{- if .Values.searchguard.enabled -}}
{{- $config = $.Values.searchguard.kibana.image -}}
{{- $base = "kublr/kibana-sg" -}}
{{- end -}}
{{- include "image" (list $config $base $ ) }}
{{- end -}}


{{- define "logstash.image" -}}
{{- $name := default "logstash/logstash-oss" $.Values.logstash.image.name -}}
{{- if .Values.elasticsearch.xpackEnabled -}}
{{- $name = default "logstash/logstash" $.Values.logstash.image.name -}}
{{- end -}}
{{- $.Values.logstash.image.registry }}/{{- $name -}}:{{ $.Values.logstash.image.tag }}
{{- end -}}
